@@ -1,5 +1,5 @@
-import re
 import hashlib
+import re
 from typing import TYPE_CHECKING, Union
 
 from jinja2 import StrictUndefined, Template
@@ -9,9 +9,9 @@ from metrics_layer.core.exceptions import (
     QueryError,
 )
 
-from .definitions import Definitions
 from .base import MetricsLayerBase, SQLReplacement
 from .field import Field, ZenlyticFieldType
+from .filter import Filter
 from .join import ZenlyticJoinRelationship, ZenlyticJoinType
 from .join_graph import IdentifierTypes
 from .set import Set
@@ -61,6 +61,94 @@ class View(MetricsLayerBase, SQLReplacement):
     def id(self):
         return self.name
 
+    def secure_from_statement(self, query_type: str) -> str:
+        """
+        Generate a secure FROM statement that applies access filters to the query.
+
+        This method respects the sql_table_name first when present, and the derived_table
+        when the derived_table is present. Access filters are applied the same way they are
+        in the query design framework.
+
+        Returns
+        -------
+        str
+            A secure FROM statement with access filters applied, or the base table/view reference
+            if no access filters are present.
+        """
+        from metrics_layer.core.sql.query_design import MetricsLayerDesign
+
+        self.design = MetricsLayerDesign(
+            no_group_by=False,
+            query_type=query_type,
+            field_lookup={},
+            topic=None,
+            model=self.model,
+            project=self.project,
+        )
+        access_filter_literal, access_filter_fields = self.design.get_access_filter(specific_view=self)
+        always_filter_literal = self._always_filter_literal()
+        if access_filter_fields:
+            for field in access_filter_fields:
+                if field.view.name != self.name:
+                    raise QueryError(
+                        f"Access filter with field {field.id()} in the view {self.name} is not supported in"
+                        " exploratory mode because the field is in a different view. Please use a derived"
+                        " table to join the views needed to apply access filter logic across multiple views."
+                    )
+        if access_filter_literal and always_filter_literal:
+            filter_literal = access_filter_literal + " and " + always_filter_literal
+        elif access_filter_literal and not always_filter_literal:
+            filter_literal = access_filter_literal
+        elif not access_filter_literal and always_filter_literal:
+            filter_literal = always_filter_literal
+        else:
+            filter_literal = None
+
+        # Get the base table reference - prioritize sql_table_name, then derived_table
+        if self.derived_table_sql:
+            base_clause = f"({self.derived_table_sql})"
+        elif self.sql_table_name:
+            base_clause = f"{self.sql_table_name}"
+        else:
+            raise QueryError(f"View {self.name} has neither sql_table_name nor derived_table defined")
+
+        if filter_literal:
+            return f"(select * from {base_clause} WHERE {filter_literal}) as {self.name}"
+        else:
+            return f"{base_clause} as {self.name}"
+
+    def _always_filter_literal(self):
+        to_add = {"week_start_day": self.model.week_start_day, "timezone": self.project.timezone}
+        parsed_filters = []
+        if self.always_filter:
+            for f in self.always_filter:
+                if "." in f["field"]:
+                    view_name = f["field"].split(".")[0]
+                    if view_name != self.name:
+                        raise QueryError(
+                            f"Always filter field {f['field']} in the view {self.name} is not supported in"
+                            " exploratory mode because it is in a different view. Please use a derived table"
+                            " to apply always filter logic across multiple views."
+                        )
+                if "." not in f["field"]:
+                    f["field"] = f"{self.name}.{f['field']}"
+                filter_dicts = Filter({**f, **to_add}).filter_dict(json_safe=False)
+                for filter_dict in filter_dicts:
+                    field_datatype = self.project.get_field(f["field"]).type
+                    parsed_filters.append(
+                        str(
+                            Filter.sql_query(
+                                f["field"],
+                                filter_dict["expression"],
+                                filter_dict["value"],
+                                field_datatype,
+                            )
+                        )
+                    )
+        if parsed_filters:
+            return " and ".join(parsed_filters)
+        return None
+
     @property
     def sql_table_name(self):
         if "sql_table_name" in self._definition:
@@ -155,7 +243,7 @@ class View(MetricsLayerBase, SQLReplacement):
         return None
 
     @property
-    def model(self):
+    def model(self) -> "Model":
         try:
             if "model_name" in self._definition:
                 model: Model = self.project.get_model(self._definition["model_name"])
@@ -163,6 +251,12 @@ class View(MetricsLayerBase, SQLReplacement):
             elif "model" in self._definition:
                 model: Model = self._definition["model"]
                 return model
+            else:
+                raise AccessDeniedOrDoesNotExistException(
+                    f"Could not find or you do not have access to model {self.model_name}",
+                    object_name=self.model_name,
+                    object_type="model",
+                )
         except AccessDeniedOrDoesNotExistException as e:
             e.message = str(e) + f" in view {self.name}"
             raise e
@@ -1013,7 +1107,7 @@ class View(MetricsLayerBase, SQLReplacement):
                 referenced_sql = field.get_referenced_sql_query(strings_only=False)
                 if referenced_sql is not None:
                     for reference in referenced_sql:
-                        if isinstance(reference, str) and field.is_personal_field:
+                        if isinstance(reference, str) and field.is_dynamic_field:
                             all_fields.append((field, f"Warning: {reference}"))
                         elif isinstance(reference, str):
                             all_fields.append((field, reference))
@@ -1022,7 +1116,11 @@ class View(MetricsLayerBase, SQLReplacement):
             result.extend(all_fields)
         return result
 
-    def fields(self, show_hidden: bool = True, expand_dimension_groups: bool = False) -> list:
+    def fields(
+        self,
+        show_hidden: bool = True,
+        expand_dimension_groups: bool = False,
+    ) -> list:
         if not self.__all_fields:
             self.__all_fields = self._all_fields(expand_dimension_groups=expand_dimension_groups)
         all_fields = self.__all_fields
