@@ -44,7 +44,13 @@ class MergedSQLQueryResolver(SingleSQLQueryResolver):
 
     def get_query(self, semicolon: bool = True):
         self.parse_field_names(self.where, self.having, self.order_by)
-        self.derive_sub_queries()
+        try:
+            self.derive_sub_queries()
+        except QueryError as e:
+            if self.kwargs.get("topic"):
+                self.derive_sub_queries(topic=self.kwargs.get("topic"))
+            else:
+                raise e
 
         queries_to_join = {}
         join_hashes = list(self.query_metrics.keys())
@@ -63,8 +69,19 @@ class MergedSQLQueryResolver(SingleSQLQueryResolver):
 
             # Overwrite the limit arg because these are subqueries
             kws = {**self.kwargs, "limit": None, "return_pypika_query": True}
-            # Remove the topic when trying to execute a merged result
-            kws.pop("topic", None)
+            # Remove the topic when trying to execute a merged result if and only if
+            # there are merged metrics. This is because the topic is not supported in
+            # merged result queries.
+            if topic := self.kwargs.get("topic"):
+                topic_view_names = [v.name for v in topic._views()]
+                all_dimensions_in_topic = all(d.split(".")[0] in topic_view_names for d in dimensions)
+            else:
+                all_dimensions_in_topic = False
+
+            should_use_topic = len(self.merged_metrics) == 0 and all_dimensions_in_topic
+            if not should_use_topic:
+                kws.pop("topic", None)
+
             resolver = SingleSQLQueryResolver(
                 metrics=metrics,
                 dimensions=dimensions,
@@ -102,6 +119,7 @@ class MergedSQLQueryResolver(SingleSQLQueryResolver):
             "limit": self.limit,
             "return_pypika_query": self.return_pypika_query,
             "project": self.project,
+            "is_using_topic": should_use_topic,
         }
         # Druid does not allow semicolons
         if self.query_type in Definitions.no_semicolon_warehouses:
@@ -112,7 +130,7 @@ class MergedSQLQueryResolver(SingleSQLQueryResolver):
 
         return query
 
-    def derive_sub_queries(self):
+    def derive_sub_queries(self, topic=None):
         self.query_metrics = defaultdict(list)
         self.merged_metrics = []
         self.secondary_metrics = []
@@ -185,8 +203,23 @@ class MergedSQLQueryResolver(SingleSQLQueryResolver):
                     dimension_mapping[key].append(
                         {"from_join_hash": mapping_data["from_join_hash"], **map_to}
                     )
+        # We need to get the join hashes for all dimensions, so if we are in a topic
+        # we can add all non-canon date dimensions to each join hash
+        dimension_join_hashes = set()
+        for dimension in self.dimensions:
+            field = self.project.get_field(dimension)
+            field_key = f"{field.view.name}.{field.name}"
+            join_group_hash = self._join_hash_key(field)
+            if field_key in canon_dates:
+                join_hash = f'{field_key.replace(".", "_")}__{join_group_hash}'
+                dimension_join_hashes.add(join_hash)
+
+                dimension_group = field.dimension_group
+                for mapping_info in dimension_mapping[field_key]:
+                    dimension_join_hashes.add(mapping_info["from_join_hash"])
 
         self.query_dimensions = defaultdict(list)
+        all_join_hashes = set(self.query_metrics.keys()).union(dimension_join_hashes)
         for dimension in self.dimensions:
             field = self.project.get_field(dimension)
             field_key = f"{field.view.name}.{field.name}"
@@ -201,6 +234,10 @@ class MergedSQLQueryResolver(SingleSQLQueryResolver):
                     ref_field = self.project.get_field(key)
                     self.query_dimensions[mapping_info["from_join_hash"]].append(ref_field)
             else:
+                if topic:
+                    for join_key in all_join_hashes:
+                        self.query_dimensions[join_key].append(field)
+                    continue
                 not_in_metrics = True
                 for join_hash in used_join_hashes:
                     # If the dimension is available in the same join subgraph as the metric, attach it
